import * as pulumi from "@pulumi/pulumi";
/**
 * Used to install the certificate authority certificate and update the certificate authority status.
 */
export declare class CertificateAuthorityActivation extends pulumi.CustomResource {
    /**
     * Get an existing CertificateAuthorityActivation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CertificateAuthorityActivation;
    /**
     * Returns true if the given object is an instance of CertificateAuthorityActivation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CertificateAuthorityActivation;
    /**
     * Certificate Authority certificate that will be installed in the Certificate Authority.
     */
    readonly certificate: pulumi.Output<string>;
    /**
     * Arn of the Certificate Authority.
     */
    readonly certificateAuthorityArn: pulumi.Output<string>;
    /**
     * Certificate chain for the Certificate Authority certificate.
     */
    readonly certificateChain: pulumi.Output<string | undefined>;
    /**
     * The complete certificate chain, including the Certificate Authority certificate.
     */
    readonly completeCertificateChain: pulumi.Output<string>;
    /**
     * The status of the Certificate Authority.
     */
    readonly status: pulumi.Output<string | undefined>;
    /**
     * Create a CertificateAuthorityActivation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CertificateAuthorityActivationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CertificateAuthorityActivation resource.
 */
export interface CertificateAuthorityActivationArgs {
    /**
     * Certificate Authority certificate that will be installed in the Certificate Authority.
     */
    certificate: pulumi.Input<string>;
    /**
     * Arn of the Certificate Authority.
     */
    certificateAuthorityArn: pulumi.Input<string>;
    /**
     * Certificate chain for the Certificate Authority certificate.
     */
    certificateChain?: pulumi.Input<string>;
    /**
     * The status of the Certificate Authority.
     */
    status?: pulumi.Input<string>;
}
