import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::Blueprint Resource Type
 */
export declare class Blueprint extends pulumi.CustomResource {
    /**
     * Get an existing Blueprint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Blueprint;
    /**
     * Returns true if the given object is an instance of Blueprint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Blueprint;
    /**
     * ARN of a Blueprint
     */
    readonly blueprintArn: pulumi.Output<string>;
    /**
     * Name of the Blueprint
     */
    readonly blueprintName: pulumi.Output<string>;
    /**
     * Stage of the Blueprint
     */
    readonly blueprintStage: pulumi.Output<enums.bedrock.BlueprintStage>;
    /**
     * Creation timestamp
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * KMS encryption context
     */
    readonly kmsEncryptionContext: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * KMS key identifier
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * Last modified timestamp
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * Schema of the blueprint
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Bedrock::Blueprint` for more information about the expected schema for this property.
     */
    readonly schema: pulumi.Output<any>;
    /**
     * List of Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Modality Type
     */
    readonly type: pulumi.Output<enums.bedrock.BlueprintType>;
    /**
     * Create a Blueprint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BlueprintArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Blueprint resource.
 */
export interface BlueprintArgs {
    /**
     * Name of the Blueprint
     */
    blueprintName?: pulumi.Input<string>;
    /**
     * KMS encryption context
     */
    kmsEncryptionContext?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * KMS key identifier
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * Schema of the blueprint
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Bedrock::Blueprint` for more information about the expected schema for this property.
     */
    schema: any;
    /**
     * List of Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Modality Type
     */
    type: pulumi.Input<enums.bedrock.BlueprintType>;
}
