import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::Guardrail Resource Type
 */
export declare function getGuardrail(args: GetGuardrailArgs, opts?: pulumi.InvokeOptions): Promise<GetGuardrailResult>;
export interface GetGuardrailArgs {
    /**
     * Arn representation for the guardrail
     */
    guardrailArn: string;
}
export interface GetGuardrailResult {
    /**
     * Messaging for when violations are detected in text
     */
    readonly blockedInputMessaging?: string;
    /**
     * Messaging for when violations are detected in text
     */
    readonly blockedOutputsMessaging?: string;
    /**
     * The content filter policies to configure for the guardrail.
     */
    readonly contentPolicyConfig?: outputs.bedrock.GuardrailContentPolicyConfig;
    readonly contextualGroundingPolicyConfig?: outputs.bedrock.GuardrailContextualGroundingPolicyConfig;
    /**
     * Time Stamp
     */
    readonly createdAt?: string;
    /**
     * Description of the guardrail or its version
     */
    readonly description?: string;
    /**
     * List of failure recommendations
     */
    readonly failureRecommendations?: string[];
    /**
     * Arn representation for the guardrail
     */
    readonly guardrailArn?: string;
    /**
     * Unique id for the guardrail
     */
    readonly guardrailId?: string;
    /**
     * The KMS key with which the guardrail was encrypted at rest
     */
    readonly kmsKeyArn?: string;
    /**
     * Name of the guardrail
     */
    readonly name?: string;
    /**
     * The sensitive information policy to configure for the guardrail.
     */
    readonly sensitiveInformationPolicyConfig?: outputs.bedrock.GuardrailSensitiveInformationPolicyConfig;
    /**
     * The status of the guardrail.
     */
    readonly status?: enums.bedrock.GuardrailStatus;
    /**
     * List of status reasons
     */
    readonly statusReasons?: string[];
    /**
     * List of Tags
     */
    readonly tags?: outputs.Tag[];
    /**
     * The topic policies to configure for the guardrail.
     */
    readonly topicPolicyConfig?: outputs.bedrock.GuardrailTopicPolicyConfig;
    /**
     * Time Stamp
     */
    readonly updatedAt?: string;
    /**
     * Guardrail version
     */
    readonly version?: string;
    /**
     * The word policy you configure for the guardrail.
     */
    readonly wordPolicyConfig?: outputs.bedrock.GuardrailWordPolicyConfig;
}
/**
 * Definition of AWS::Bedrock::Guardrail Resource Type
 */
export declare function getGuardrailOutput(args: GetGuardrailOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGuardrailResult>;
export interface GetGuardrailOutputArgs {
    /**
     * Arn representation for the guardrail
     */
    guardrailArn: pulumi.Input<string>;
}
