import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::Cassandra::Type
 */
export declare class Type extends pulumi.CustomResource {
    /**
     * Get an existing Type resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Type;
    /**
     * Returns true if the given object is an instance of Type.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Type;
    /**
     * List of parent User-Defined Types that directly reference the User-Defined Type in their fields.
     */
    readonly directParentTypes: pulumi.Output<string[]>;
    /**
     * List of Tables that directly reference the User-Defined Type in their columns.
     */
    readonly directReferringTables: pulumi.Output<string[]>;
    /**
     * Field definitions of the User-Defined Type
     */
    readonly fields: pulumi.Output<outputs.cassandra.TypeField[]>;
    /**
     * ARN of the Keyspace which contains the User-Defined Type.
     */
    readonly keyspaceArn: pulumi.Output<string>;
    /**
     * Name of the Keyspace which contains the User-Defined Type.
     */
    readonly keyspaceName: pulumi.Output<string>;
    /**
     * Timestamp of the last time the User-Defined Type's meta data was modified.
     */
    readonly lastModifiedTimestamp: pulumi.Output<number>;
    /**
     * Maximum nesting depth of the User-Defined Type across the field types.
     */
    readonly maxNestingDepth: pulumi.Output<number>;
    /**
     * Name of the User-Defined Type.
     */
    readonly typeName: pulumi.Output<string>;
    /**
     * Create a Type resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Type resource.
 */
export interface TypeArgs {
    /**
     * Field definitions of the User-Defined Type
     */
    fields: pulumi.Input<pulumi.Input<inputs.cassandra.TypeFieldArgs>[]>;
    /**
     * Name of the Keyspace which contains the User-Defined Type.
     */
    keyspaceName: pulumi.Input<string>;
    /**
     * Name of the User-Defined Type.
     */
    typeName?: pulumi.Input<string>;
}
