import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * This is a CloudFormation resource for the first-party AWS::Hooks::LambdaHook.
 */
export declare class LambdaHook extends pulumi.CustomResource {
    /**
     * Get an existing LambdaHook resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LambdaHook;
    /**
     * Returns true if the given object is an instance of LambdaHook.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LambdaHook;
    /**
     * The typename alias for the hook.
     */
    readonly alias: pulumi.Output<string>;
    /**
     * The execution role ARN assumed by Hooks to invoke Lambda.
     */
    readonly executionRole: pulumi.Output<string>;
    /**
     * Attribute to specify CloudFormation behavior on hook failure.
     */
    readonly failureMode: pulumi.Output<enums.cloudformation.LambdaHookFailureMode>;
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    readonly hookArn: pulumi.Output<string>;
    /**
     * Attribute to specify which stacks this hook applies to or should get invoked for
     */
    readonly hookStatus: pulumi.Output<enums.cloudformation.LambdaHookHookStatus>;
    /**
     * Amazon Resource Name (ARN), Partial ARN, name, version, or alias of the Lambda function to invoke with this hook.
     */
    readonly lambdaFunction: pulumi.Output<string>;
    /**
     * Filters to allow hooks to target specific stack attributes
     */
    readonly stackFilters: pulumi.Output<outputs.cloudformation.StackFiltersProperties | undefined>;
    /**
     * Attribute to specify which targets should invoke the hook
     */
    readonly targetFilters: pulumi.Output<outputs.cloudformation.TargetFilters0Properties | outputs.cloudformation.TargetFilters1Properties | undefined>;
    /**
     * Which operations should this Hook run against? Resource changes, stacks or change sets.
     */
    readonly targetOperations: pulumi.Output<enums.cloudformation.LambdaHookTargetOperation[]>;
    /**
     * Create a LambdaHook resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LambdaHookArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LambdaHook resource.
 */
export interface LambdaHookArgs {
    /**
     * The typename alias for the hook.
     */
    alias: pulumi.Input<string>;
    /**
     * The execution role ARN assumed by Hooks to invoke Lambda.
     */
    executionRole: pulumi.Input<string>;
    /**
     * Attribute to specify CloudFormation behavior on hook failure.
     */
    failureMode: pulumi.Input<enums.cloudformation.LambdaHookFailureMode>;
    /**
     * Attribute to specify which stacks this hook applies to or should get invoked for
     */
    hookStatus: pulumi.Input<enums.cloudformation.LambdaHookHookStatus>;
    /**
     * Amazon Resource Name (ARN), Partial ARN, name, version, or alias of the Lambda function to invoke with this hook.
     */
    lambdaFunction: pulumi.Input<string>;
    /**
     * Filters to allow hooks to target specific stack attributes
     */
    stackFilters?: pulumi.Input<inputs.cloudformation.StackFiltersPropertiesArgs>;
    /**
     * Attribute to specify which targets should invoke the hook
     */
    targetFilters?: pulumi.Input<inputs.cloudformation.TargetFilters0PropertiesArgs | inputs.cloudformation.TargetFilters1PropertiesArgs>;
    /**
     * Which operations should this Hook run against? Resource changes, stacks or change sets.
     */
    targetOperations: pulumi.Input<pulumi.Input<enums.cloudformation.LambdaHookTargetOperation>[]>;
}
