import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Connect::ViewVersion
 */
export declare class ViewVersion extends pulumi.CustomResource {
    /**
     * Get an existing ViewVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ViewVersion;
    /**
     * Returns true if the given object is an instance of ViewVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ViewVersion;
    /**
     * The version of the view.
     */
    readonly version: pulumi.Output<number>;
    /**
     * The description for the view version.
     */
    readonly versionDescription: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the view for which a version is being created.
     */
    readonly viewArn: pulumi.Output<string>;
    /**
     * The view content hash to be checked.
     */
    readonly viewContentSha256: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the created view version.
     */
    readonly viewVersionArn: pulumi.Output<string>;
    /**
     * Create a ViewVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ViewVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ViewVersion resource.
 */
export interface ViewVersionArgs {
    /**
     * The description for the view version.
     */
    versionDescription?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the view for which a version is being created.
     */
    viewArn: pulumi.Input<string>;
    /**
     * The view content hash to be checked.
     */
    viewContentSha256?: pulumi.Input<string>;
}
