import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::Deadline::MeteredProduct Resource Type
 */
export declare class MeteredProduct extends pulumi.CustomResource {
    /**
     * Get an existing MeteredProduct resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MeteredProduct;
    /**
     * Returns true if the given object is an instance of MeteredProduct.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MeteredProduct;
    /**
     * The Amazon Resource Name (ARN) of the metered product.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The family to which the metered product belongs.
     */
    readonly family: pulumi.Output<string>;
    /**
     * The Amazon EC2 identifier of the license endpoint.
     */
    readonly licenseEndpointId: pulumi.Output<string | undefined>;
    /**
     * The port on which the metered product should run.
     */
    readonly port: pulumi.Output<number>;
    /**
     * The product ID.
     */
    readonly productId: pulumi.Output<string | undefined>;
    /**
     * The vendor.
     */
    readonly vendor: pulumi.Output<string>;
    /**
     * Create a MeteredProduct resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: MeteredProductArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MeteredProduct resource.
 */
export interface MeteredProductArgs {
    /**
     * The Amazon EC2 identifier of the license endpoint.
     */
    licenseEndpointId?: pulumi.Input<string>;
    /**
     * The product ID.
     */
    productId?: pulumi.Input<string>;
}
