import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::EFS::AccessPoint`` resource creates an EFS access point. An access point is an application-specific view into an EFS file system that applies an operating system user and group, and a file system path, to any file system request made through the access point. The operating system user and group override any identity information provided by the NFS client. The file system path is exposed as the access point's root directory. Applications using the access point can only access data in its own directory and below. To learn more, see [Mounting a file system using EFS access points](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html).
 *  This operation requires permissions for the ``elasticfilesystem:CreateAccessPoint`` action.
 */
export declare function getAccessPoint(args: GetAccessPointArgs, opts?: pulumi.InvokeOptions): Promise<GetAccessPointResult>;
export interface GetAccessPointArgs {
    /**
     * The ID of the EFS access point.
     */
    accessPointId: string;
}
export interface GetAccessPointResult {
    /**
     * The ID of the EFS access point.
     */
    readonly accessPointId?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     *  For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).
     */
    readonly accessPointTags?: outputs.Tag[];
    /**
     * The Amazon Resource Name (ARN) of the access point.
     */
    readonly arn?: string;
}
/**
 * The ``AWS::EFS::AccessPoint`` resource creates an EFS access point. An access point is an application-specific view into an EFS file system that applies an operating system user and group, and a file system path, to any file system request made through the access point. The operating system user and group override any identity information provided by the NFS client. The file system path is exposed as the access point's root directory. Applications using the access point can only access data in its own directory and below. To learn more, see [Mounting a file system using EFS access points](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html).
 *  This operation requires permissions for the ``elasticfilesystem:CreateAccessPoint`` action.
 */
export declare function getAccessPointOutput(args: GetAccessPointOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccessPointResult>;
export interface GetAccessPointOutputArgs {
    /**
     * The ID of the EFS access point.
     */
    accessPointId: pulumi.Input<string>;
}
