import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::IAM::ServiceLinkedRole
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const basicSLR = new aws_native.iam.ServiceLinkedRole("basicSLR", {
 *     awsServiceName: "autoscaling.amazonaws.com",
 *     description: "Test SLR description",
 *     customSuffix: "TestSuffix",
 * });
 * export const slrId = basicSLR.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const basicSLR = new aws_native.iam.ServiceLinkedRole("basicSLR", {
 *     awsServiceName: "autoscaling.amazonaws.com",
 *     description: "Test SLR description",
 *     customSuffix: "TestSuffix",
 * });
 * export const slrId = basicSLR.id;
 *
 * ```
 */
export declare class ServiceLinkedRole extends pulumi.CustomResource {
    /**
     * Get an existing ServiceLinkedRole resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceLinkedRole;
    /**
     * Returns true if the given object is an instance of ServiceLinkedRole.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceLinkedRole;
    /**
     * The service principal for the AWS service to which this role is attached.
     */
    readonly awsServiceName: pulumi.Output<string | undefined>;
    /**
     * A string that you provide, which is combined with the service-provided prefix to form the complete role name.
     */
    readonly customSuffix: pulumi.Output<string | undefined>;
    /**
     * The description of the role.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the role.
     */
    readonly roleName: pulumi.Output<string>;
    /**
     * Create a ServiceLinkedRole resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServiceLinkedRoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceLinkedRole resource.
 */
export interface ServiceLinkedRoleArgs {
    /**
     * The service principal for the AWS service to which this role is attached.
     */
    awsServiceName?: pulumi.Input<string>;
    /**
     * A string that you provide, which is combined with the service-provided prefix to form the complete role name.
     */
    customSuffix?: pulumi.Input<string>;
    /**
     * The description of the role.
     */
    description?: pulumi.Input<string>;
}
