import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const testSuiteDefinition = new aws_native.iotcoredeviceadvisor.SuiteDefinition("testSuiteDefinition", {suiteDefinitionConfiguration: {
 *     suiteDefinitionName: "SuiteDefinitionName",
 *     devicePermissionRoleArn: "arn:aws:iam::123456789012:role/RoleName",
 *     devices: [{
 *         thingArn: "arn:aws:iot:us-east-1:123456789012:thing/ThingName",
 *     }],
 *     rootGroup: `{
 * "configuration": {},
 * "tests": [{
 * "name": "TestGroup",
 * "configuration": {
 * "EXECUTION_TIMEOUT": "30"
 * },
 * "tests": [{
 * "name": "MQTTPublishTest",
 * "configuration": {
 * "TOPIC_FOR_PUBLISH_VALIDATION": "target"
 * },
 * "test": {
 * "id": "MQTT_Publish",
 * "version": "0.0.0"
 * }
 * }]
 * }]
 * }`,
 *     intendedForQualification: false,
 * }});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const testSuiteDefinition = new aws_native.iotcoredeviceadvisor.SuiteDefinition("testSuiteDefinition", {suiteDefinitionConfiguration: {
 *     suiteDefinitionName: "SuiteDefinitionName",
 *     devicePermissionRoleArn: "arn:aws:iam::123456789012:role/RoleName",
 *     devices: [{
 *         thingArn: "arn:aws:iot:us-east-1:123456789012:thing/ThingName",
 *     }],
 *     rootGroup: "{ \"configuration\": {}, \"tests\": [{ \"name\": \"TestGroup\", \"configuration\": { \"EXECUTION_TIMEOUT\": \"30\" }, \"tests\": [{ \"name\": \"MQTTPublishTest\", \"configuration\": { \"TOPIC_FOR_PUBLISH_VALIDATION\": \"target\" }, \"test\": { \"id\": \"MQTT_Publish\", \"version\": \"0.0.0\" } }] }] }",
 *     intendedForQualification: false,
 * }});
 *
 * ```
 */
export declare class SuiteDefinition extends pulumi.CustomResource {
    /**
     * Get an existing SuiteDefinition resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SuiteDefinition;
    /**
     * Returns true if the given object is an instance of SuiteDefinition.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SuiteDefinition;
    /**
     * The Amazon Resource name for the suite definition.
     */
    readonly suiteDefinitionArn: pulumi.Output<string>;
    /**
     * The configuration of the Suite Definition. Listed below are the required elements of the `SuiteDefinitionConfiguration` .
     *
     * - ***devicePermissionRoleArn*** - The device permission arn.
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***devices*** - The list of configured devices under test. For more information on devices under test, see [DeviceUnderTest](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_DeviceUnderTest.html)
     *
     * Not a required element.
     *
     * *Type:* List of devices under test
     * - ***intendedForQualification*** - The tests intended for qualification in a suite.
     *
     * Not a required element.
     *
     * *Type:* Boolean
     * - ***rootGroup*** - The test suite root group. For more information on creating and using root groups see the [Device Advisor workflow](https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html) .
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***suiteDefinitionName*** - The Suite Definition Configuration name.
     *
     * This is a required element.
     *
     * *Type:* String
     */
    readonly suiteDefinitionConfiguration: pulumi.Output<outputs.iotcoredeviceadvisor.SuiteDefinitionConfigurationProperties>;
    /**
     * The unique identifier for the suite definition.
     */
    readonly suiteDefinitionId: pulumi.Output<string>;
    /**
     * The suite definition version of a test suite.
     */
    readonly suiteDefinitionVersion: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SuiteDefinition resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SuiteDefinitionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SuiteDefinition resource.
 */
export interface SuiteDefinitionArgs {
    /**
     * The configuration of the Suite Definition. Listed below are the required elements of the `SuiteDefinitionConfiguration` .
     *
     * - ***devicePermissionRoleArn*** - The device permission arn.
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***devices*** - The list of configured devices under test. For more information on devices under test, see [DeviceUnderTest](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_DeviceUnderTest.html)
     *
     * Not a required element.
     *
     * *Type:* List of devices under test
     * - ***intendedForQualification*** - The tests intended for qualification in a suite.
     *
     * Not a required element.
     *
     * *Type:* Boolean
     * - ***rootGroup*** - The test suite root group. For more information on creating and using root groups see the [Device Advisor workflow](https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html) .
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***suiteDefinitionName*** - The Suite Definition Configuration name.
     *
     * This is a required element.
     *
     * *Type:* String
     */
    suiteDefinitionConfiguration: pulumi.Input<inputs.iotcoredeviceadvisor.SuiteDefinitionConfigurationPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
