import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::IoTEvents::Input resource creates an input. To monitor your devices and processes, they must have a way to get telemetry data into ITE. This is done by sending messages as *inputs* to ITE. For more information, see [How to Use](https://docs.aws.amazon.com/iotevents/latest/developerguide/how-to-use-iotevents.html) in the *Developer Guide*.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myInput = new aws_native.iotevents.Input("myInput", {
 *     inputName: "myInput",
 *     inputDescription: "My Input created by CloudFormation",
 *     inputDefinition: {
 *         attributes: [
 *             {
 *                 jsonPath: "foo",
 *             },
 *             {
 *                 jsonPath: "bar",
 *             },
 *         ],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myInput = new aws_native.iotevents.Input("myInput", {
 *     inputName: "myInput",
 *     inputDescription: "My Input created by CloudFormation",
 *     inputDefinition: {
 *         attributes: [
 *             {
 *                 jsonPath: "foo",
 *             },
 *             {
 *                 jsonPath: "bar",
 *             },
 *         ],
 *     },
 * });
 *
 * ```
 */
export declare class Input extends pulumi.CustomResource {
    /**
     * Get an existing Input resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Input;
    /**
     * Returns true if the given object is an instance of Input.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Input;
    /**
     * The definition of the input.
     */
    readonly inputDefinition: pulumi.Output<outputs.iotevents.InputDefinition>;
    /**
     * A brief description of the input.
     */
    readonly inputDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the input.
     */
    readonly inputName: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     *  For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Input resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InputArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Input resource.
 */
export interface InputArgs {
    /**
     * The definition of the input.
     */
    inputDefinition: pulumi.Input<inputs.iotevents.InputDefinitionArgs>;
    /**
     * A brief description of the input.
     */
    inputDescription?: pulumi.Input<string>;
    /**
     * The name of the input.
     */
    inputName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *  For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
