import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTTwinMaker::Entity
 */
export declare class Entity extends pulumi.CustomResource {
    /**
     * Get an existing Entity resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Entity;
    /**
     * Returns true if the given object is an instance of Entity.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Entity;
    /**
     * The ARN of the entity.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A map that sets information about a component type.
     */
    readonly components: pulumi.Output<{
        [key: string]: outputs.iottwinmaker.EntityComponent;
    } | undefined>;
    /**
     * A map that sets information about a composite component.
     */
    readonly compositeComponents: pulumi.Output<{
        [key: string]: outputs.iottwinmaker.EntityCompositeComponent;
    } | undefined>;
    /**
     * The date and time when the entity was created.
     */
    readonly creationDateTime: pulumi.Output<string>;
    /**
     * The description of the entity.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the entity.
     */
    readonly entityId: pulumi.Output<string | undefined>;
    /**
     * The name of the entity.
     */
    readonly entityName: pulumi.Output<string>;
    /**
     * A Boolean value that specifies whether the entity has child entities or not.
     */
    readonly hasChildEntities: pulumi.Output<boolean>;
    /**
     * The ID of the parent entity.
     */
    readonly parentEntityId: pulumi.Output<string | undefined>;
    /**
     * The current status of the entity.
     */
    readonly status: pulumi.Output<outputs.iottwinmaker.EntityStatus>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The last date and time when the entity was updated.
     */
    readonly updateDateTime: pulumi.Output<string>;
    /**
     * The ID of the workspace.
     */
    readonly workspaceId: pulumi.Output<string>;
    /**
     * Create a Entity resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EntityArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Entity resource.
 */
export interface EntityArgs {
    /**
     * A map that sets information about a component type.
     */
    components?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.iottwinmaker.EntityComponentArgs>;
    }>;
    /**
     * A map that sets information about a composite component.
     */
    compositeComponents?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.iottwinmaker.EntityCompositeComponentArgs>;
    }>;
    /**
     * The description of the entity.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the entity.
     */
    entityId?: pulumi.Input<string>;
    /**
     * The name of the entity.
     */
    entityName?: pulumi.Input<string>;
    /**
     * The ID of the parent entity.
     */
    parentEntityId?: pulumi.Input<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the workspace.
     */
    workspaceId: pulumi.Input<string>;
}
