import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Create and manage wireless gateways, including LoRa gateways.
 */
export declare class WirelessDevice extends pulumi.CustomResource {
    /**
     * Get an existing WirelessDevice resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WirelessDevice;
    /**
     * Returns true if the given object is an instance of WirelessDevice.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WirelessDevice;
    /**
     * Wireless device arn. Returned after successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Wireless device Id. Returned after successful create.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Wireless device description
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Wireless device destination name
     */
    readonly destinationName: pulumi.Output<string>;
    /**
     * The date and time when the most recent uplink was received.
     */
    readonly lastUplinkReceivedAt: pulumi.Output<string | undefined>;
    /**
     * The combination of Package, Station and Model which represents the version of the LoRaWAN Wireless Device.
     */
    readonly loRaWan: pulumi.Output<outputs.iotwireless.WirelessDeviceLoRaWanDevice | undefined>;
    /**
     * Wireless device name
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * FPort values for the GNSS, stream, and ClockSync functions of the positioning information.
     */
    readonly positioning: pulumi.Output<enums.iotwireless.WirelessDevicePositioning | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the device. Currently not supported, will not create if tags are passed.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Thing arn. Passed into update to associate Thing with Wireless device.
     */
    readonly thingArn: pulumi.Output<string | undefined>;
    /**
     * Thing Arn. If there is a Thing created, this can be returned with a Get call.
     */
    readonly thingName: pulumi.Output<string>;
    /**
     * Wireless device type, currently only Sidewalk and LoRa
     */
    readonly type: pulumi.Output<enums.iotwireless.WirelessDeviceType>;
    /**
     * Create a WirelessDevice resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WirelessDeviceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WirelessDevice resource.
 */
export interface WirelessDeviceArgs {
    /**
     * Wireless device description
     */
    description?: pulumi.Input<string>;
    /**
     * Wireless device destination name
     */
    destinationName: pulumi.Input<string>;
    /**
     * The date and time when the most recent uplink was received.
     */
    lastUplinkReceivedAt?: pulumi.Input<string>;
    /**
     * The combination of Package, Station and Model which represents the version of the LoRaWAN Wireless Device.
     */
    loRaWan?: pulumi.Input<inputs.iotwireless.WirelessDeviceLoRaWanDeviceArgs>;
    /**
     * Wireless device name
     */
    name?: pulumi.Input<string>;
    /**
     * FPort values for the GNSS, stream, and ClockSync functions of the positioning information.
     */
    positioning?: pulumi.Input<enums.iotwireless.WirelessDevicePositioning>;
    /**
     * A list of key-value pairs that contain metadata for the device. Currently not supported, will not create if tags are passed.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Thing arn. Passed into update to associate Thing with Wireless device.
     */
    thingArn?: pulumi.Input<string>;
    /**
     * Wireless device type, currently only Sidewalk and LoRa
     */
    type: pulumi.Input<enums.iotwireless.WirelessDeviceType>;
}
