import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A Kendra FAQ resource
 */
export declare function getFaq(args: GetFaqArgs, opts?: pulumi.InvokeOptions): Promise<GetFaqResult>;
export interface GetFaqArgs {
    /**
     * The identifier for the FAQ. For example:
     *
     * `f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    id: string;
    /**
     * Index ID
     */
    indexId: string;
}
export interface GetFaqResult {
    /**
     * `arn:aws:kendra:us-west-2:111122223333:index/335c3741-41df-46a6-b5d3-61f85b787884/faq/f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    readonly arn?: string;
    /**
     * The identifier for the FAQ. For example:
     *
     * `f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    readonly id?: string;
    /**
     * The code for a language. This shows a supported language for the FAQ document as part of the summary information for FAQs. English is supported by default. For more information on supported languages, including their codes, see [Adding documents in languages other than English](https://docs.aws.amazon.com/kendra/latest/dg/in-adding-languages.html) .
     */
    readonly languageCode?: string;
    /**
     * Tags for labeling the FAQ
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A Kendra FAQ resource
 */
export declare function getFaqOutput(args: GetFaqOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFaqResult>;
export interface GetFaqOutputArgs {
    /**
     * The identifier for the FAQ. For example:
     *
     * `f61995a6-cd5c-4e99-9cfc-58816d8bfaa7`
     */
    id: pulumi.Input<string>;
    /**
     * Index ID
     */
    indexId: pulumi.Input<string>;
}
