import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type Definition for AWS::KinesisVideo::SignalingChannel
 */
export declare function getSignalingChannel(args: GetSignalingChannelArgs, opts?: pulumi.InvokeOptions): Promise<GetSignalingChannelResult>;
export interface GetSignalingChannelArgs {
    /**
     * The name of the Kinesis Video Signaling Channel.
     */
    name: string;
}
export interface GetSignalingChannelResult {
    /**
     * The Amazon Resource Name (ARN) of the Kinesis Video Signaling Channel.
     */
    readonly arn?: string;
    /**
     * The period of time a signaling channel retains undelivered messages before they are discarded.
     */
    readonly messageTtlSeconds?: number;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The type of the Kinesis Video Signaling Channel to create. Currently, SINGLE_MASTER is the only supported channel type.
     */
    readonly type?: enums.kinesisvideo.SignalingChannelType;
}
/**
 * Resource Type Definition for AWS::KinesisVideo::SignalingChannel
 */
export declare function getSignalingChannelOutput(args: GetSignalingChannelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSignalingChannelResult>;
export interface GetSignalingChannelOutputArgs {
    /**
     * The name of the Kinesis Video Signaling Channel.
     */
    name: pulumi.Input<string>;
}
