import * as pulumi from "@pulumi/pulumi";
/**
 * Schema for Lambda LayerVersionPermission
 */
export declare class LayerVersionPermission extends pulumi.CustomResource {
    /**
     * Get an existing LayerVersionPermission resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LayerVersionPermission;
    /**
     * Returns true if the given object is an instance of LayerVersionPermission.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LayerVersionPermission;
    /**
     * The API action that grants access to the layer.
     */
    readonly action: pulumi.Output<string>;
    /**
     * ID generated by service
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The name or Amazon Resource Name (ARN) of the layer.
     */
    readonly layerVersionArn: pulumi.Output<string>;
    /**
     * With the principal set to *, grant permission to all accounts in the specified organization.
     */
    readonly organizationId: pulumi.Output<string | undefined>;
    /**
     * An account ID, or * to grant layer usage permission to all accounts in an organization, or all AWS accounts (if organizationId is not specified).
     */
    readonly principal: pulumi.Output<string>;
    /**
     * Create a LayerVersionPermission resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LayerVersionPermissionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LayerVersionPermission resource.
 */
export interface LayerVersionPermissionArgs {
    /**
     * The API action that grants access to the layer.
     */
    action: pulumi.Input<string>;
    /**
     * The name or Amazon Resource Name (ARN) of the layer.
     */
    layerVersionArn: pulumi.Input<string>;
    /**
     * With the principal set to *, grant permission to all accounts in the specified organization.
     */
    organizationId?: pulumi.Input<string>;
    /**
     * An account ID, or * to grant layer usage permission to all accounts in an organization, or all AWS accounts (if organizationId is not specified).
     */
    principal: pulumi.Input<string>;
}
