import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lightsail::Instance
 */
export declare function getInstance(args: GetInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetInstanceResult>;
export interface GetInstanceArgs {
    /**
     * The names to use for your new Lightsail instance.
     */
    instanceName: string;
}
export interface GetInstanceResult {
    /**
     * An array of objects representing the add-ons to enable for the new instance.
     */
    readonly addOns?: outputs.lightsail.InstanceAddOn[];
    /**
     * The hardware properties for the instance, such as the vCPU count, attached disks, and amount of RAM.
     *
     * > The instance restarts when performing an attach disk or detach disk request. This resets the public IP address of your instance if a static IP isn't attached to it.
     */
    readonly hardware?: outputs.lightsail.InstanceHardware;
    /**
     * The Amazon Resource Name (ARN) of the instance (for example, `arn:aws:lightsail:us-east-2:123456789101:Instance/244ad76f-8aad-4741-809f-12345EXAMPLE` ).
     */
    readonly instanceArn?: string;
    /**
     * IPv6 addresses of the instance
     */
    readonly ipv6Addresses?: string[];
    /**
     * Is the IP Address of the Instance is the static IP
     */
    readonly isStaticIp?: boolean;
    /**
     * The name of your key pair.
     */
    readonly keyPairName?: string;
    /**
     * The location for the instance, such as the AWS Region and Availability Zone.
     *
     * > The `Location` property is read-only and should not be specified in a create instance or update instance request.
     */
    readonly location?: outputs.lightsail.InstanceLocation;
    /**
     * The public ports and the monthly amount of data transfer allocated for the instance.
     */
    readonly networking?: outputs.lightsail.InstanceNetworking;
    /**
     * Private IP Address of the Instance
     */
    readonly privateIpAddress?: string;
    /**
     * Public IP Address of the Instance
     */
    readonly publicIpAddress?: string;
    /**
     * Resource type of Lightsail instance.
     */
    readonly resourceType?: string;
    /**
     * SSH Key Name of the  Lightsail instance.
     */
    readonly sshKeyName?: string;
    /**
     * The status code and the state (for example, `running` ) of the instance.
     *
     * > The `State` property is read-only and should not be specified in a create instance or update instance request.
     */
    readonly state?: outputs.lightsail.InstanceState;
    /**
     * Support code to help identify any issues
     */
    readonly supportCode?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Username of the  Lightsail instance.
     */
    readonly userName?: string;
}
/**
 * Resource Type definition for AWS::Lightsail::Instance
 */
export declare function getInstanceOutput(args: GetInstanceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInstanceResult>;
export interface GetInstanceOutputArgs {
    /**
     * The names to use for your new Lightsail instance.
     */
    instanceName: pulumi.Input<string>;
}
