import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The AWS::Macie::Session resource specifies a new Amazon Macie session. A session is an object that represents the Amazon Macie service. A session is required for Amazon Macie to become operational.
 */
export declare function getSession(args: GetSessionArgs, opts?: pulumi.InvokeOptions): Promise<GetSessionResult>;
export interface GetSessionArgs {
    /**
     * AWS account ID of customer
     */
    awsAccountId: string;
}
export interface GetSessionResult {
    /**
     * AWS account ID of customer
     */
    readonly awsAccountId?: string;
    /**
     * A enumeration value that specifies how frequently finding updates are published.
     */
    readonly findingPublishingFrequency?: enums.macie.SessionFindingPublishingFrequency;
    /**
     * Service role used by Macie
     */
    readonly serviceRole?: string;
    /**
     * A enumeration value that specifies the status of the Macie Session.
     */
    readonly status?: enums.macie.SessionStatus;
}
/**
 * The AWS::Macie::Session resource specifies a new Amazon Macie session. A session is an object that represents the Amazon Macie service. A session is required for Amazon Macie to become operational.
 */
export declare function getSessionOutput(args: GetSessionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSessionResult>;
export interface GetSessionOutputArgs {
    /**
     * AWS account ID of customer
     */
    awsAccountId: pulumi.Input<string>;
}
