import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The AWS::Macie::Session resource specifies a new Amazon Macie session. A session is an object that represents the Amazon Macie service. A session is required for Amazon Macie to become operational.
 */
export declare class Session extends pulumi.CustomResource {
    /**
     * Get an existing Session resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Session;
    /**
     * Returns true if the given object is an instance of Session.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Session;
    /**
     * AWS account ID of customer
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * A enumeration value that specifies how frequently finding updates are published.
     */
    readonly findingPublishingFrequency: pulumi.Output<enums.macie.SessionFindingPublishingFrequency | undefined>;
    /**
     * Service role used by Macie
     */
    readonly serviceRole: pulumi.Output<string>;
    /**
     * A enumeration value that specifies the status of the Macie Session.
     */
    readonly status: pulumi.Output<enums.macie.SessionStatus | undefined>;
    /**
     * Create a Session resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SessionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Session resource.
 */
export interface SessionArgs {
    /**
     * A enumeration value that specifies how frequently finding updates are published.
     */
    findingPublishingFrequency?: pulumi.Input<enums.macie.SessionFindingPublishingFrequency>;
    /**
     * A enumeration value that specifies the status of the Macie Session.
     */
    status?: pulumi.Input<enums.macie.SessionStatus>;
}
