import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::MediaLive::Multiplexprogram
 */
export declare class Multiplexprogram extends pulumi.CustomResource {
    /**
     * Get an existing Multiplexprogram resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Multiplexprogram;
    /**
     * Returns true if the given object is an instance of Multiplexprogram.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Multiplexprogram;
    /**
     * The MediaLive channel associated with the program.
     */
    readonly channelId: pulumi.Output<string>;
    /**
     * The ID of the multiplex that the program belongs to.
     */
    readonly multiplexId: pulumi.Output<string | undefined>;
    /**
     * The settings for this multiplex program.
     */
    readonly multiplexProgramSettings: pulumi.Output<outputs.medialive.MultiplexprogramMultiplexProgramSettings | undefined>;
    /**
     * The packet identifier map for this multiplex program.
     */
    readonly packetIdentifiersMap: pulumi.Output<outputs.medialive.MultiplexprogramMultiplexProgramPacketIdentifiersMap | undefined>;
    /**
     * Contains information about the current sources for the specified program in the specified multiplex. Keep in mind that each multiplex pipeline connects to both pipelines in a given source channel (the channel identified by the program). But only one of those channel pipelines is ever active at one time.
     */
    readonly pipelineDetails: pulumi.Output<outputs.medialive.MultiplexprogramMultiplexProgramPipelineDetail[] | undefined>;
    /**
     * The settings for this multiplex program.
     */
    readonly preferredChannelPipeline: pulumi.Output<enums.medialive.MultiplexprogramPreferredChannelPipeline | undefined>;
    /**
     * The name of the multiplex program.
     */
    readonly programName: pulumi.Output<string | undefined>;
    /**
     * Create a Multiplexprogram resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: MultiplexprogramArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Multiplexprogram resource.
 */
export interface MultiplexprogramArgs {
    /**
     * The ID of the multiplex that the program belongs to.
     */
    multiplexId?: pulumi.Input<string>;
    /**
     * The settings for this multiplex program.
     */
    multiplexProgramSettings?: pulumi.Input<inputs.medialive.MultiplexprogramMultiplexProgramSettingsArgs>;
    /**
     * The packet identifier map for this multiplex program.
     */
    packetIdentifiersMap?: pulumi.Input<inputs.medialive.MultiplexprogramMultiplexProgramPacketIdentifiersMapArgs>;
    /**
     * Contains information about the current sources for the specified program in the specified multiplex. Keep in mind that each multiplex pipeline connects to both pipelines in a given source channel (the channel identified by the program). But only one of those channel pipelines is ever active at one time.
     */
    pipelineDetails?: pulumi.Input<pulumi.Input<inputs.medialive.MultiplexprogramMultiplexProgramPipelineDetailArgs>[]>;
    /**
     * The settings for this multiplex program.
     */
    preferredChannelPipeline?: pulumi.Input<enums.medialive.MultiplexprogramPreferredChannelPipeline>;
    /**
     * The name of the multiplex program.
     */
    programName?: pulumi.Input<string>;
}
