import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::MemoryDB::Multi Region Cluster resource creates an Amazon MemoryDB Multi Region Cluster.
 */
export declare function getMultiRegionCluster(args: GetMultiRegionClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetMultiRegionClusterResult>;
export interface GetMultiRegionClusterArgs {
    /**
     * The name of the Global Datastore, it is generated by MemoryDB adding a prefix to MultiRegionClusterNameSuffix.
     */
    multiRegionClusterName: string;
}
export interface GetMultiRegionClusterResult {
    /**
     * The Amazon Resource Name (ARN) of the multi region cluster.
     */
    readonly arn?: string;
    /**
     * Description of the multi region cluster.
     */
    readonly description?: string;
    /**
     * The engine type used by the multi region cluster.
     */
    readonly engine?: string;
    /**
     * The name of the Global Datastore, it is generated by MemoryDB adding a prefix to MultiRegionClusterNameSuffix.
     */
    readonly multiRegionClusterName?: string;
    /**
     * The compute and memory capacity of the nodes in the multi region cluster.
     */
    readonly nodeType?: string;
    /**
     * The number of shards the multi region cluster will contain.
     */
    readonly numShards?: number;
    /**
     * The status of the multi region cluster. For example, Available, Updating, Creating.
     */
    readonly status?: string;
    /**
     * An array of key-value pairs to apply to this multi region cluster.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::MemoryDB::Multi Region Cluster resource creates an Amazon MemoryDB Multi Region Cluster.
 */
export declare function getMultiRegionClusterOutput(args: GetMultiRegionClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMultiRegionClusterResult>;
export interface GetMultiRegionClusterOutputArgs {
    /**
     * The name of the Global Datastore, it is generated by MemoryDB adding a prefix to MultiRegionClusterNameSuffix.
     */
    multiRegionClusterName: pulumi.Input<string>;
}
