import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An OpenSearch Ingestion Service Data Prepper pipeline running Data Prepper.
 */
export declare function getPipeline(args: GetPipelineArgs, opts?: pulumi.InvokeOptions): Promise<GetPipelineResult>;
export interface GetPipelineArgs {
    /**
     * The Amazon Resource Name (ARN) of the pipeline.
     */
    pipelineArn: string;
}
export interface GetPipelineResult {
    /**
     * Options that specify the configuration of a persistent buffer. To configure how OpenSearch Ingestion encrypts this data, set the `EncryptionAtRestOptions` . For more information, see [Persistent buffering](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/osis-features-overview.html#persistent-buffering) .
     */
    readonly bufferOptions?: outputs.osis.PipelineBufferOptions;
    /**
     * Options to control how OpenSearch encrypts buffer data.
     */
    readonly encryptionAtRestOptions?: outputs.osis.PipelineEncryptionAtRestOptions;
    /**
     * A list of endpoints that can be used for ingesting data into a pipeline
     */
    readonly ingestEndpointUrls?: string[];
    /**
     * Key-value pairs that represent log publishing settings.
     */
    readonly logPublishingOptions?: outputs.osis.PipelineLogPublishingOptions;
    /**
     * The maximum pipeline capacity, in Ingestion OpenSearch Compute Units (OCUs).
     */
    readonly maxUnits?: number;
    /**
     * The minimum pipeline capacity, in Ingestion OpenSearch Compute Units (OCUs).
     */
    readonly minUnits?: number;
    /**
     * The Amazon Resource Name (ARN) of the pipeline.
     */
    readonly pipelineArn?: string;
    /**
     * The Data Prepper pipeline configuration.
     */
    readonly pipelineConfigurationBody?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The VPC endpoint service name for the pipeline.
     */
    readonly vpcEndpointService?: string;
    /**
     * The VPC interface endpoints that have access to the pipeline.
     */
    readonly vpcEndpoints?: outputs.osis.PipelineVpcEndpoint[];
}
/**
 * An OpenSearch Ingestion Service Data Prepper pipeline running Data Prepper.
 */
export declare function getPipelineOutput(args: GetPipelineOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPipelineResult>;
export interface GetPipelineOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the pipeline.
     */
    pipelineArn: pulumi.Input<string>;
}
