import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::RefactorSpaces::Application Resource Type
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The resource ID of the API Gateway for the proxy.
     */
    readonly apiGatewayId: pulumi.Output<string>;
    /**
     * The endpoint URL of the Amazon API Gateway proxy.
     */
    readonly apiGatewayProxy: pulumi.Output<outputs.refactorspaces.ApplicationApiGatewayProxyInput | undefined>;
    /**
     * The unique identifier of the application.
     */
    readonly applicationIdentifier: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the application.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The unique identifier of the environment.
     */
    readonly environmentIdentifier: pulumi.Output<string>;
    /**
     * The name of the application.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the Network Load Balancer .
     */
    readonly nlbArn: pulumi.Output<string>;
    /**
     * The name of the Network Load Balancer configured by the API Gateway proxy.
     */
    readonly nlbName: pulumi.Output<string>;
    /**
     * The proxy type of the proxy created within the application.
     */
    readonly proxyType: pulumi.Output<enums.refactorspaces.ApplicationProxyType>;
    /**
     * The endpoint URL of the Amazon API Gateway proxy.
     */
    readonly proxyUrl: pulumi.Output<string>;
    /**
     * The name of the API Gateway stage. The name defaults to `prod` .
     */
    readonly stageName: pulumi.Output<string>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the virtual private cloud (VPC).
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * The `VpcLink` ID of the API Gateway proxy.
     */
    readonly vpcLinkId: pulumi.Output<string>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The endpoint URL of the Amazon API Gateway proxy.
     */
    apiGatewayProxy?: pulumi.Input<inputs.refactorspaces.ApplicationApiGatewayProxyInputArgs>;
    /**
     * The unique identifier of the environment.
     */
    environmentIdentifier: pulumi.Input<string>;
    /**
     * The name of the application.
     */
    name?: pulumi.Input<string>;
    /**
     * The proxy type of the proxy created within the application.
     */
    proxyType: pulumi.Input<enums.refactorspaces.ApplicationProxyType>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the virtual private cloud (VPC).
     */
    vpcId: pulumi.Input<string>;
}
