import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * AWS Route53 Recovery Control Cluster resource schema
 */
export declare function getCluster(args: GetClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterResult>;
export interface GetClusterArgs {
    /**
     * The Amazon Resource Name (ARN) of the cluster.
     */
    clusterArn: string;
}
export interface GetClusterResult {
    /**
     * The Amazon Resource Name (ARN) of the cluster.
     */
    readonly clusterArn?: string;
    /**
     * Endpoints for the cluster.
     */
    readonly clusterEndpoints?: outputs.route53recoverycontrol.ClusterEndpoint[];
    /**
     * Cluster supports IPv4 endpoints and Dual-stack IPv4 and IPv6 endpoints. NetworkType can be IPV4 or DUALSTACK.
     */
    readonly networkType?: enums.route53recoverycontrol.ClusterNetworkType;
    /**
     * Deployment status of a resource. Status can be one of the following: PENDING, DEPLOYED, PENDING_DELETION.
     */
    readonly status?: enums.route53recoverycontrol.ClusterStatus;
}
/**
 * AWS Route53 Recovery Control Cluster resource schema
 */
export declare function getClusterOutput(args: GetClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetClusterResult>;
export interface GetClusterOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the cluster.
     */
    clusterArn: pulumi.Input<string>;
}
