import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::S3::AccessGrantsInstance resource is an Amazon S3 resource type that hosts Access Grants and their associated locations
 */
export declare class AccessGrantsInstance extends pulumi.CustomResource {
    /**
     * Get an existing AccessGrantsInstance resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessGrantsInstance;
    /**
     * Returns true if the given object is an instance of AccessGrantsInstance.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessGrantsInstance;
    /**
     * The Amazon Resource Name (ARN) of the specified Access Grants instance.
     */
    readonly accessGrantsInstanceArn: pulumi.Output<string>;
    /**
     * A unique identifier for the specified access grants instance.
     */
    readonly accessGrantsInstanceId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the specified AWS Identity Center.
     */
    readonly identityCenterArn: pulumi.Output<string | undefined>;
    /**
     * The AWS resource tags that you are adding to the S3 Access Grants instance. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a AccessGrantsInstance resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AccessGrantsInstanceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessGrantsInstance resource.
 */
export interface AccessGrantsInstanceArgs {
    /**
     * The Amazon Resource Name (ARN) of the specified AWS Identity Center.
     */
    identityCenterArn?: pulumi.Input<string>;
    /**
     * The AWS resource tags that you are adding to the S3 Access Grants instance. Each tag is a label consisting of a user-defined key and value. Tags can help you manage, identify, organize, search for, and filter resources.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
