import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Applies an IAM resource policy to a table bucket.
 */
export declare class TableBucketPolicy extends pulumi.CustomResource {
    /**
     * Get an existing TableBucketPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TableBucketPolicy;
    /**
     * Returns true if the given object is an instance of TableBucketPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TableBucketPolicy;
    /**
     * The bucket policy JSON for the table bucket.
     */
    readonly resourcePolicy: pulumi.Output<outputs.s3tables.TableBucketPolicyResourcePolicy>;
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    readonly tableBucketArn: pulumi.Output<string>;
    /**
     * Create a TableBucketPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TableBucketPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TableBucketPolicy resource.
 */
export interface TableBucketPolicyArgs {
    /**
     * The bucket policy JSON for the table bucket.
     */
    resourcePolicy: pulumi.Input<inputs.s3tables.TableBucketPolicyResourcePolicyArgs>;
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    tableBucketArn: pulumi.Input<string>;
}
