import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::Cluster
 */
export declare class Cluster extends pulumi.CustomResource {
    /**
     * Get an existing Cluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Cluster;
    /**
     * Returns true if the given object is an instance of Cluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Cluster;
    /**
     * The Amazon Resource Name (ARN) of the HyperPod Cluster.
     */
    readonly clusterArn: pulumi.Output<string>;
    /**
     * The name of the HyperPod Cluster.
     */
    readonly clusterName: pulumi.Output<string | undefined>;
    /**
     * The status of the HyperPod Cluster.
     */
    readonly clusterStatus: pulumi.Output<enums.sagemaker.ClusterStatus>;
    /**
     * The time at which the HyperPod cluster was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The failure message of the HyperPod Cluster.
     */
    readonly failureMessage: pulumi.Output<string>;
    /**
     * The instance groups of the SageMaker HyperPod cluster. To delete an instance group, remove it from the array.
     */
    readonly instanceGroups: pulumi.Output<outputs.sagemaker.ClusterInstanceGroup[]>;
    /**
     * If node auto-recovery is set to true, faulty nodes will be replaced or rebooted when a failure is detected. If set to false, nodes will be labelled when a fault is detected.
     */
    readonly nodeRecovery: pulumi.Output<enums.sagemaker.ClusterNodeRecovery | undefined>;
    /**
     * The orchestrator type for the SageMaker HyperPod cluster. Currently, `'eks'` is the only available option.
     */
    readonly orchestrator: pulumi.Output<outputs.sagemaker.ClusterOrchestrator | undefined>;
    /**
     * Custom tags for managing the SageMaker HyperPod cluster as an AWS resource. You can add tags to your cluster in the same way you add them in other AWS services that support tagging.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC](https://docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html) .
     */
    readonly vpcConfig: pulumi.Output<outputs.sagemaker.ClusterVpcConfig | undefined>;
    /**
     * Create a Cluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Cluster resource.
 */
export interface ClusterArgs {
    /**
     * The name of the HyperPod Cluster.
     */
    clusterName?: pulumi.Input<string>;
    /**
     * The instance groups of the SageMaker HyperPod cluster. To delete an instance group, remove it from the array.
     */
    instanceGroups: pulumi.Input<pulumi.Input<inputs.sagemaker.ClusterInstanceGroupArgs>[]>;
    /**
     * If node auto-recovery is set to true, faulty nodes will be replaced or rebooted when a failure is detected. If set to false, nodes will be labelled when a fault is detected.
     */
    nodeRecovery?: pulumi.Input<enums.sagemaker.ClusterNodeRecovery>;
    /**
     * The orchestrator type for the SageMaker HyperPod cluster. Currently, `'eks'` is the only available option.
     */
    orchestrator?: pulumi.Input<inputs.sagemaker.ClusterOrchestratorArgs>;
    /**
     * Custom tags for managing the SageMaker HyperPod cluster as an AWS resource. You can add tags to your cluster in the same way you add them in other AWS services that support tagging.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC](https://docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html) .
     */
    vpcConfig?: pulumi.Input<inputs.sagemaker.ClusterVpcConfigArgs>;
}
