import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::PartnerApp
 */
export declare function getPartnerApp(args: GetPartnerAppArgs, opts?: pulumi.InvokeOptions): Promise<GetPartnerAppResult>;
export interface GetPartnerAppArgs {
    /**
     * The Amazon Resource Name (ARN) of the created PartnerApp.
     */
    arn: string;
}
export interface GetPartnerAppResult {
    /**
     * A collection of settings that specify the maintenance schedule for the PartnerApp.
     */
    readonly applicationConfig?: outputs.sagemaker.PartnerAppConfig;
    /**
     * The Amazon Resource Name (ARN) of the created PartnerApp.
     */
    readonly arn?: string;
    /**
     * The AppServerUrl based on app and account-info.
     */
    readonly baseUrl?: string;
    /**
     * Enables IAM Session based Identity for PartnerApp.
     */
    readonly enableIamSessionBasedIdentity?: boolean;
    /**
     * A collection of settings that specify the maintenance schedule for the PartnerApp.
     */
    readonly maintenanceConfig?: outputs.sagemaker.PartnerAppMaintenanceConfig;
    /**
     * A list of tags to apply to the PartnerApp.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The tier of the PartnerApp.
     */
    readonly tier?: string;
}
/**
 * Resource Type definition for AWS::SageMaker::PartnerApp
 */
export declare function getPartnerAppOutput(args: GetPartnerAppOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPartnerAppResult>;
export interface GetPartnerAppOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the created PartnerApp.
     */
    arn: pulumi.Input<string>;
}
