import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::Project
 */
export declare function getProject(args: GetProjectArgs, opts?: pulumi.InvokeOptions): Promise<GetProjectResult>;
export interface GetProjectArgs {
    /**
     * The Amazon Resource Name (ARN) of the project.
     */
    projectArn: string;
}
export interface GetProjectResult {
    /**
     * The time at which the project was created.
     */
    readonly creationTime?: string;
    /**
     * The Amazon Resource Name (ARN) of the project.
     */
    readonly projectArn?: string;
    /**
     * The ID of the project. This ID is prepended to all entities associated with this project.
     */
    readonly projectId?: string;
    /**
     * The status of a project.
     */
    readonly projectStatus?: enums.sagemaker.ProjectStatus;
    /**
     * Provisioned ServiceCatalog  Details
     */
    readonly serviceCatalogProvisionedProductDetails?: outputs.sagemaker.ServiceCatalogProvisionedProductDetailsProperties;
}
/**
 * Resource Type definition for AWS::SageMaker::Project
 */
export declare function getProjectOutput(args: GetProjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProjectResult>;
export interface GetProjectOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the project.
     */
    projectArn: pulumi.Input<string>;
}
