import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::ImageVersion
 */
export declare class ImageVersion extends pulumi.CustomResource {
    /**
     * Get an existing ImageVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ImageVersion;
    /**
     * Returns true if the given object is an instance of ImageVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ImageVersion;
    readonly alias: pulumi.Output<string | undefined>;
    readonly aliases: pulumi.Output<string[] | undefined>;
    /**
     * The container image that the SageMaker image version is based on.
     */
    readonly baseImage: pulumi.Output<string>;
    /**
     * The URI of the container image version referenced by ImageVersion.
     */
    readonly containerImage: pulumi.Output<string>;
    readonly horovod: pulumi.Output<boolean | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the parent Image.
     */
    readonly imageArn: pulumi.Output<string>;
    /**
     * The name of the parent image.
     *
     * *Length Constraints* : Minimum length of 1. Maximum length of 63.
     *
     * *Pattern* : `^[a-zA-Z0-9]([-.]?[a-zA-Z0-9]){0,62}$`
     */
    readonly imageName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the image version.
     *
     * *Type* : String
     *
     * *Length Constraints* : Maximum length of 256.
     *
     * *Pattern* : `^arn:aws(-[\w]+)*:sagemaker:.+:[0-9]{12}:image-version/[a-z0-9]([-.]?[a-z0-9])*&#47;[0-9]+$`
     */
    readonly imageVersionArn: pulumi.Output<string>;
    readonly jobType: pulumi.Output<enums.sagemaker.ImageVersionJobType | undefined>;
    readonly mlFramework: pulumi.Output<string | undefined>;
    readonly processor: pulumi.Output<enums.sagemaker.ImageVersionProcessor | undefined>;
    readonly programmingLang: pulumi.Output<string | undefined>;
    readonly releaseNotes: pulumi.Output<string | undefined>;
    readonly vendorGuidance: pulumi.Output<enums.sagemaker.ImageVersionVendorGuidance | undefined>;
    /**
     * The version of the image.
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a ImageVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ImageVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ImageVersion resource.
 */
export interface ImageVersionArgs {
    alias?: pulumi.Input<string>;
    aliases?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The container image that the SageMaker image version is based on.
     */
    baseImage: pulumi.Input<string>;
    horovod?: pulumi.Input<boolean>;
    /**
     * The name of the parent image.
     *
     * *Length Constraints* : Minimum length of 1. Maximum length of 63.
     *
     * *Pattern* : `^[a-zA-Z0-9]([-.]?[a-zA-Z0-9]){0,62}$`
     */
    imageName: pulumi.Input<string>;
    jobType?: pulumi.Input<enums.sagemaker.ImageVersionJobType>;
    mlFramework?: pulumi.Input<string>;
    processor?: pulumi.Input<enums.sagemaker.ImageVersionProcessor>;
    programmingLang?: pulumi.Input<string>;
    releaseNotes?: pulumi.Input<string>;
    vendorGuidance?: pulumi.Input<enums.sagemaker.ImageVersionVendorGuidance>;
}
