import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::SecurityHub::ConfigurationPolicy resource represents the Central Configuration Policy in your account.
 */
export declare function getConfigurationPolicy(args: GetConfigurationPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetConfigurationPolicyResult>;
export interface GetConfigurationPolicyArgs {
    /**
     * The Amazon Resource Name (ARN) of the configuration policy.
     */
    arn: string;
}
export interface GetConfigurationPolicyResult {
    /**
     * The Amazon Resource Name (ARN) of the configuration policy.
     */
    readonly arn?: string;
    /**
     * An object that defines how AWS Security Hub is configured. It includes whether Security Hub is enabled or disabled, a list of enabled security standards, a list of enabled or disabled security controls, and a list of custom parameter values for specified controls. If you provide a list of security controls that are enabled in the configuration policy, Security Hub disables all other controls (including newly released controls). If you provide a list of security controls that are disabled in the configuration policy, Security Hub enables all other controls (including newly released controls).
     */
    readonly configurationPolicy?: outputs.securityhub.ConfigurationPolicyPolicy;
    /**
     * The date and time, in UTC and ISO 8601 format.
     */
    readonly createdAt?: string;
    /**
     * The description of the configuration policy.
     */
    readonly description?: string;
    /**
     * The universally unique identifier (UUID) of the configuration policy.
     */
    readonly id?: string;
    /**
     * The name of the configuration policy.
     */
    readonly name?: string;
    /**
     * Indicates whether the service that the configuration policy applies to is enabled in the policy.
     */
    readonly serviceEnabled?: boolean;
    /**
     * User-defined tags associated with a configuration policy. For more information, see [Tagging AWS Security Hub resources](https://docs.aws.amazon.com/securityhub/latest/userguide/tagging-resources.html) in the *Security Hub user guide* .
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The date and time, in UTC and ISO 8601 format.
     */
    readonly updatedAt?: string;
}
/**
 * The AWS::SecurityHub::ConfigurationPolicy resource represents the Central Configuration Policy in your account.
 */
export declare function getConfigurationPolicyOutput(args: GetConfigurationPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfigurationPolicyResult>;
export interface GetConfigurationPolicyOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the configuration policy.
     */
    arn: pulumi.Input<string>;
}
