import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Schema for AWS::ServiceCatalogAppRegistry::ResourceAssociation
 */
export declare class ResourceAssociation extends pulumi.CustomResource {
    /**
     * Get an existing ResourceAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResourceAssociation;
    /**
     * Returns true if the given object is an instance of ResourceAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResourceAssociation;
    /**
     * The name or the Id of the Application.
     */
    readonly application: pulumi.Output<string>;
    /**
     * The Amazon resource name (ARN) that specifies the application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * The name or the Id of the Resource.
     */
    readonly resource: pulumi.Output<string>;
    /**
     * The Amazon resource name (ARN) that specifies the resource.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The type of the CFN Resource for now it's enum CFN_STACK.
     */
    readonly resourceType: pulumi.Output<enums.servicecatalogappregistry.ResourceAssociationResourceType>;
    /**
     * Create a ResourceAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResourceAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResourceAssociation resource.
 */
export interface ResourceAssociationArgs {
    /**
     * The name or the Id of the Application.
     */
    application: pulumi.Input<string>;
    /**
     * The name or the Id of the Resource.
     */
    resource: pulumi.Input<string>;
    /**
     * The type of the CFN Resource for now it's enum CFN_STACK.
     */
    resourceType: pulumi.Input<enums.servicecatalogappregistry.ResourceAssociationResourceType>;
}
