import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for SSO assignmet
 */
export declare class Assignment extends pulumi.CustomResource {
    /**
     * Get an existing Assignment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Assignment;
    /**
     * Returns true if the given object is an instance of Assignment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Assignment;
    /**
     * The sso instance that the permission set is owned.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The permission set that the assignemt will be assigned
     */
    readonly permissionSetArn: pulumi.Output<string>;
    /**
     * The assignee's identifier, user id/group id
     */
    readonly principalId: pulumi.Output<string>;
    /**
     * The assignee's type, user/group
     */
    readonly principalType: pulumi.Output<enums.sso.AssignmentPrincipalType>;
    /**
     * The account id to be provisioned.
     */
    readonly targetId: pulumi.Output<string>;
    /**
     * The type of resource to be provsioned to, only aws account now
     */
    readonly targetType: pulumi.Output<enums.sso.AssignmentTargetType>;
    /**
     * Create a Assignment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AssignmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Assignment resource.
 */
export interface AssignmentArgs {
    /**
     * The sso instance that the permission set is owned.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The permission set that the assignemt will be assigned
     */
    permissionSetArn: pulumi.Input<string>;
    /**
     * The assignee's identifier, user id/group id
     */
    principalId: pulumi.Input<string>;
    /**
     * The assignee's type, user/group
     */
    principalType: pulumi.Input<enums.sso.AssignmentPrincipalType>;
    /**
     * The account id to be provisioned.
     */
    targetId: pulumi.Input<string>;
    /**
     * The type of resource to be provsioned to, only aws account now
     */
    targetType: pulumi.Input<enums.sso.AssignmentTargetType>;
}
