import * as pulumi from "@pulumi/pulumi";
/**
 * An AWS Support App resource that creates, updates, lists, and deletes Slack workspace configurations.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const slackWorkspaceConfiguration = new aws_native.supportapp.SlackWorkspaceConfiguration("slackWorkspaceConfiguration", {
 *     teamId: "T012ABCDEFG",
 *     versionId: "1",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const slackWorkspaceConfiguration = new aws_native.supportapp.SlackWorkspaceConfiguration("slackWorkspaceConfiguration", {
 *     teamId: "T012ABCDEFG",
 *     versionId: "1",
 * });
 *
 * ```
 */
export declare class SlackWorkspaceConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing SlackWorkspaceConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SlackWorkspaceConfiguration;
    /**
     * Returns true if the given object is an instance of SlackWorkspaceConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SlackWorkspaceConfiguration;
    /**
     * The team ID in Slack, which uniquely identifies a workspace.
     */
    readonly teamId: pulumi.Output<string>;
    /**
     * An identifier used to update an existing Slack workspace configuration in AWS CloudFormation.
     */
    readonly versionId: pulumi.Output<string | undefined>;
    /**
     * Create a SlackWorkspaceConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SlackWorkspaceConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SlackWorkspaceConfiguration resource.
 */
export interface SlackWorkspaceConfigurationArgs {
    /**
     * The team ID in Slack, which uniquely identifies a workspace.
     */
    teamId: pulumi.Input<string>;
    /**
     * An identifier used to update an existing Slack workspace configuration in AWS CloudFormation.
     */
    versionId?: pulumi.Input<string>;
}
