import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A service network is a logical boundary for a collection of services. You can associate services and VPCs with a service network.
 */
export declare function getServiceNetwork(args: GetServiceNetworkArgs, opts?: pulumi.InvokeOptions): Promise<GetServiceNetworkResult>;
export interface GetServiceNetworkArgs {
    /**
     * The Amazon Resource Name (ARN) of the service network.
     */
    arn: string;
}
export interface GetServiceNetworkResult {
    /**
     * The Amazon Resource Name (ARN) of the service network.
     */
    readonly arn?: string;
    /**
     * The type of IAM policy.
     *
     * - `NONE` : The resource does not use an IAM policy. This is the default.
     * - `AWS_IAM` : The resource uses an IAM policy. When this type is used, auth is enabled and an auth policy is required.
     */
    readonly authType?: enums.vpclattice.ServiceNetworkAuthType;
    /**
     * The date and time that the service network was created, specified in ISO-8601 format.
     */
    readonly createdAt?: string;
    /**
     * The ID of the service network.
     */
    readonly id?: string;
    /**
     * The date and time of the last update, specified in ISO-8601 format.
     */
    readonly lastUpdatedAt?: string;
    /**
     * Specify if the service network should be enabled for sharing.
     */
    readonly sharingConfig?: outputs.vpclattice.ServiceNetworkSharingConfig;
    /**
     * The tags for the service network.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A service network is a logical boundary for a collection of services. You can associate services and VPCs with a service network.
 */
export declare function getServiceNetworkOutput(args: GetServiceNetworkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetServiceNetworkResult>;
export interface GetServiceNetworkOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the service network.
     */
    arn: pulumi.Input<string>;
}
