import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::WorkSpaces::ConnectionAlias
 */
export declare class ConnectionAlias extends pulumi.CustomResource {
    /**
     * Get an existing ConnectionAlias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConnectionAlias;
    /**
     * Returns true if the given object is an instance of ConnectionAlias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConnectionAlias;
    /**
     * The identifier of the connection alias, returned as a string.
     */
    readonly aliasId: pulumi.Output<string>;
    /**
     * The association status of the connection alias.
     */
    readonly associations: pulumi.Output<outputs.workspaces.ConnectionAliasAssociation[]>;
    /**
     * The current state of the connection alias, returned as a string.
     */
    readonly connectionAliasState: pulumi.Output<enums.workspaces.ConnectionAliasState>;
    /**
     * The connection string specified for the connection alias. The connection string must be in the form of a fully qualified domain name (FQDN), such as `www.example.com` .
     */
    readonly connectionString: pulumi.Output<string>;
    /**
     * The tags to associate with the connection alias.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a ConnectionAlias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConnectionAliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConnectionAlias resource.
 */
export interface ConnectionAliasArgs {
    /**
     * The connection string specified for the connection alias. The connection string must be in the form of a fully qualified domain name (FQDN), such as `www.example.com` .
     */
    connectionString: pulumi.Input<string>;
    /**
     * The tags to associate with the connection alias.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
