import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::WorkSpacesWeb::NetworkSettings Resource Type
 */
export declare function getNetworkSettings(args: GetNetworkSettingsArgs, opts?: pulumi.InvokeOptions): Promise<GetNetworkSettingsResult>;
export interface GetNetworkSettingsArgs {
    /**
     * The ARN of the network settings.
     */
    networkSettingsArn: string;
}
export interface GetNetworkSettingsResult {
    /**
     * A list of web portal ARNs that this network settings is associated with.
     */
    readonly associatedPortalArns?: string[];
    /**
     * The ARN of the network settings.
     */
    readonly networkSettingsArn?: string;
    /**
     * One or more security groups used to control access from streaming instances to your VPC.
     *
     * *Pattern* : `^[\w+\-]+$`
     */
    readonly securityGroupIds?: string[];
    /**
     * The subnets in which network interfaces are created to connect streaming instances to your VPC. At least two of these subnets must be in different availability zones.
     *
     * *Pattern* : `^subnet-([0-9a-f]{8}|[0-9a-f]{17})$`
     */
    readonly subnetIds?: string[];
    /**
     * The tags to add to the network settings resource. A tag is a key-value pair.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The VPC that streaming instances will connect to.
     *
     * *Pattern* : `^vpc-[0-9a-z]*$`
     */
    readonly vpcId?: string;
}
/**
 * Definition of AWS::WorkSpacesWeb::NetworkSettings Resource Type
 */
export declare function getNetworkSettingsOutput(args: GetNetworkSettingsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetNetworkSettingsResult>;
export interface GetNetworkSettingsOutputArgs {
    /**
     * The ARN of the network settings.
     */
    networkSettingsArn: pulumi.Input<string>;
}
