import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::WorkSpacesWeb::NetworkSettings Resource Type
 */
export declare class NetworkSettings extends pulumi.CustomResource {
    /**
     * Get an existing NetworkSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NetworkSettings;
    /**
     * Returns true if the given object is an instance of NetworkSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkSettings;
    /**
     * A list of web portal ARNs that this network settings is associated with.
     */
    readonly associatedPortalArns: pulumi.Output<string[]>;
    /**
     * The ARN of the network settings.
     */
    readonly networkSettingsArn: pulumi.Output<string>;
    /**
     * One or more security groups used to control access from streaming instances to your VPC.
     *
     * *Pattern* : `^[\w+\-]+$`
     */
    readonly securityGroupIds: pulumi.Output<string[]>;
    /**
     * The subnets in which network interfaces are created to connect streaming instances to your VPC. At least two of these subnets must be in different availability zones.
     *
     * *Pattern* : `^subnet-([0-9a-f]{8}|[0-9a-f]{17})$`
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * The tags to add to the network settings resource. A tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The VPC that streaming instances will connect to.
     *
     * *Pattern* : `^vpc-[0-9a-z]*$`
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a NetworkSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NetworkSettings resource.
 */
export interface NetworkSettingsArgs {
    /**
     * One or more security groups used to control access from streaming instances to your VPC.
     *
     * *Pattern* : `^[\w+\-]+$`
     */
    securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The subnets in which network interfaces are created to connect streaming instances to your VPC. At least two of these subnets must be in different availability zones.
     *
     * *Pattern* : `^subnet-([0-9a-f]{8}|[0-9a-f]{17})$`
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags to add to the network settings resource. A tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The VPC that streaming instances will connect to.
     *
     * *Pattern* : `^vpc-[0-9a-z]*$`
     */
    vpcId: pulumi.Input<string>;
}
